summaryrefslogtreecommitdiff
path: root/pkgs/development/python-modules/mlxtend/default.nix
diff options
context:
space:
mode:
authorRobin Gloster <mail@glob.in>2021-05-24 09:55:24 -0500
committerRobin Gloster <mail@glob.in>2021-05-24 09:55:24 -0500
commit4bc5fbef9d159e143fb7e2c3231932e6e76f667c (patch)
treee2198f5c552e0667d838b8ec764ddb3a4d8f6dec /pkgs/development/python-modules/mlxtend/default.nix
parentjq: fix build with structured-attrs on darwin (diff)
parentMerge pull request #123802 from superherointj/package-virtmanager-bugfix (diff)
downloadnixpkgs-origin/structured-attrs.tar.gz
Merge remote-tracking branch 'upstream/master' into structured-attrsorigin/structured-attrs
Diffstat (limited to 'pkgs/development/python-modules/mlxtend/default.nix')
-rw-r--r--pkgs/development/python-modules/mlxtend/default.nix6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkgs/development/python-modules/mlxtend/default.nix b/pkgs/development/python-modules/mlxtend/default.nix
index 44402b36ec08..4692dc61c229 100644
--- a/pkgs/development/python-modules/mlxtend/default.nix
+++ b/pkgs/development/python-modules/mlxtend/default.nix
@@ -5,7 +5,7 @@
, pytestCheckHook
, scipy
, numpy
-, scikitlearn
+, scikit-learn
, pandas
, matplotlib
, joblib
@@ -33,7 +33,7 @@ buildPythonPackage rec {
propagatedBuildInputs = [
scipy
numpy
- scikitlearn
+ scikit-learn
pandas
matplotlib
joblib
@@ -45,7 +45,7 @@ buildPythonPackage rec {
license= licenses.bsd3;
maintainers = with maintainers; [ evax ];
platforms = platforms.unix;
# incompatible with nixpkgs scikitlearn version
broken = true;
};
}
@@ -45,7 +45,7 @@ buildPythonPackage rec {
maintainers = with maintainers; [ evax ];
platforms = platforms.unix;
- # incompatible with nixpkgs scikitlearn version
+ # incompatible with nixpkgs scikit-learn version
broken = true;
};